local L = LibStub("AceLocale-3.0"):GetLocale("HitsMode5")
local deletefilter = nil


HitsMode5.options = {
	name = "HitsMode5         r|cff20ff20"..HitsMode5.MINOR_VERSION.."|r",
	handler = HitsMode5,
	type = "group",
	args = {		
		
		filters = {
			type = "group",
			name = L["Filters"],
			order = 2,
			args = {

				create = {
					type = "input",
					name = L["Create filter"],
					desc = L["Enter the name for the new filter."],
					set = function(self, val) if val and val ~= "" then HitsMode5:CreateFilter(val) end end,
					order = 1,
				},

				delete = {
					type = "select",
					name = L["Delete filter"],
					desc = L["Choose the filter to be deleted."],
					values =	function()
						local filters = {}
						for k, v in ipairs(HitsMode5:GetFilters()) do
							filters[v.db.name] = v.db.name
						end
						return filters
					end,
					get = function() return deletefilter end,
					set = function(self, val) deletefilter = val end,
					order = 2,
				},
				
				deleteexecute = {
					type = "execute",
					name = L["Delete filter"],
					desc = L["Deletes the chosen filter."],
					confirm = true,
					confirmText = L["Are you sure you want to delete this filter?"],
					func = function(self) if deletefilter then HitsMode5:DeleteFilter(deletefilter) end end,
					order = 3,
				},

			},
		}, -- filters

		
		help = {
			type = "group",
			name = L["Help"],
			order = 999,
			
			args = {
				help = {
					type = "execute",
					name = L["Help with HitsMode5"],
					func = function()
						InterfaceOptionsFrame:Hide()
						ToggleHelpFrame()
						HitsMode5:ScheduleTimer("CheckHelpLoaded", 0.2)
					end,
					order = 999
				}
			} -- args
		}, -- help
		
	} -- args
} -- options


HitsMode5.defaults = {
 profile = {
		filters = {}
 },
}


HitsMode5.filterDefaults = {
	enabled = true,
	events = {
  ["ENVIRONMENTAL_DAMAGE"] = true,
  ["SWING_DAMAGE"] = true,
  ["SWING_MISSED"] = true,
  ["RANGE_DAMAGE"] = true,
  ["RANGE_MISSED"] = true,
  --["SPELL_CAST_START"] = true,
  --["SPELL_CAST_SUCCESS"] = true,
  --["SPELL_CAST_FAILED"] = true,
  ["SPELL_MISSED"] = true,
  ["SPELL_DAMAGE"] = true,
  ["SPELL_HEAL"] = true,
  ["SPELL_ENERGIZE"] = true,
  ["SPELL_DRAIN"] = true,
  ["SPELL_LEECH"] = true,
  ["SPELL_INSTAKILL"] = true,
  ["SPELL_INTERRUPT"] = true,
  ["SPELL_EXTRA_ATTACKS"] = true,
  --["SPELL_DURABILITY_DAMAGE"] = true,
  --["SPELL_DURABILITY_DAMAGE_ALL"] = true,
  ["SPELL_AURA_APPLIED"] = true,
  ["SPELL_AURA_APPLIED_DOSE"] = true,
  ["SPELL_AURA_REMOVED"] = true,
  ["SPELL_AURA_REMOVED_DOSE"] = true,
  ["SPELL_DISPEL"] = true,
  ["SPELL_STOLEN"] = true,
  ["ENCHANT_APPLIED"] = true,
  ["ENCHANT_REMOVED"] = true,
  ["SPELL_PERIODIC_MISSED"] = true,
  ["SPELL_PERIODIC_DAMAGE"] = true,
  ["SPELL_PERIODIC_HEAL"] = true,
  ["SPELL_PERIODIC_ENERGIZE"] = true,
  ["SPELL_PERIODIC_DRAIN"] = true,
  ["SPELL_PERIODIC_LEECH"] = true,
  ["SPELL_DISPEL_FAILED"] = true,
  ["DAMAGE_SHIELD"] = true,
  ["DAMAGE_SHIELD_MISSED"] = true,
  ["DAMAGE_SPLIT"] = true,
  ["PARTY_KILL"] = true,
  ["UNIT_DIED"] = true,
  ["UNIT_DESTROYED"] = true,
  ["UNIT_DISSIPATES"] = true,
  -- Blizzard Combat Log doesn't handle events below
		["SPELL_BUILDING_HEAL"] = true,
		["SPELL_BUILDING_DAMAGE"] = true,
		["SPELL_SUMMON"] = true,
		["SPELL_CREATE"] = true,
		["SPELL_RESURRECT"] = true,
		["SPELL_AURA_REFRESH"] = true,
		["SPELL_AURA_BROKEN"] = true,
		["SPELL_AURA_BROKEN_SPELL"] = true,
	},
	specialEvents = {
		["CHAT_MSG_COMBAT_XP_GAIN"] = true,
		["CHAT_MSG_LOOT"] = true,
		["CHAT_MSG_COMBAT_FACTION_CHANGE"] = true,
		["CHAT_MSG_COMBAT_HONOR_GAIN"] = true,
		["CHAT_MSG_MONEY"] = true,
		["CHAT_MSG_SKILL"] = true,
	},
	sourceFlags = {
		[COMBATLOG_OBJECT_AFFILIATION_MINE] = true,
		[COMBATLOG_OBJECT_AFFILIATION_PARTY] = true,
		[COMBATLOG_OBJECT_AFFILIATION_RAID] = true,
		[COMBATLOG_OBJECT_AFFILIATION_OUTSIDER] = true,
		[COMBATLOG_OBJECT_REACTION_FRIENDLY] = true,
		[COMBATLOG_OBJECT_REACTION_NEUTRAL] = true,
		[COMBATLOG_OBJECT_REACTION_HOSTILE] = true,
		[COMBATLOG_OBJECT_CONTROL_PLAYER] = true,
		[COMBATLOG_OBJECT_CONTROL_NPC] = true,
		[COMBATLOG_OBJECT_TYPE_PLAYER] = true,
		[COMBATLOG_OBJECT_TYPE_NPC] = true,
		[COMBATLOG_OBJECT_TYPE_PET] = true,
		[COMBATLOG_OBJECT_TYPE_GUARDIAN] = true,
		[COMBATLOG_OBJECT_TYPE_OBJECT] = true
	},
	destFlags = {
		[COMBATLOG_OBJECT_AFFILIATION_MINE] = true,
		[COMBATLOG_OBJECT_AFFILIATION_PARTY] = true,
		[COMBATLOG_OBJECT_AFFILIATION_RAID] = true,
		[COMBATLOG_OBJECT_AFFILIATION_OUTSIDER] = true,
		[COMBATLOG_OBJECT_REACTION_FRIENDLY] = true,
		[COMBATLOG_OBJECT_REACTION_NEUTRAL] = true,
		[COMBATLOG_OBJECT_REACTION_HOSTILE] = true,
		[COMBATLOG_OBJECT_CONTROL_PLAYER] = true,
		[COMBATLOG_OBJECT_CONTROL_NPC] = true,
		[COMBATLOG_OBJECT_TYPE_PLAYER] = true,
		[COMBATLOG_OBJECT_TYPE_NPC] = true,
		[COMBATLOG_OBJECT_TYPE_PET] = true,
		[COMBATLOG_OBJECT_TYPE_GUARDIAN] = true,
		[COMBATLOG_OBJECT_TYPE_OBJECT] = true
	},
	sourceWhiteList = "",
	sourceBlackList = "",
	destWhiteList = "",
	destBlackList = ""
}

